@@ -45,7 +45,7 @@ void KDirListerTest::initTestCase()
     // To avoid failing on broken locally defined MIME types
     QStandardPaths::setTestModeEnabled(true);
 
-    m_tempDir.reset(new QTemporaryDir(homeTmpDir()));
+    m_tempDir.reset(new QTemporaryDir(tmpDirTemplate()));
 
     // No message dialogs
     KIO::setDefaultJobUiDelegateExtension(nullptr);
@@ -123,6 +123,7 @@ void KDirListerTest::testOpenUrl()
 
     // then wait for completed
     qDebug("waiting for completed");
+    QTRY_VERIFY(m_dirLister.isFinished());
     QTRY_COMPARE(m_dirLister.spyStarted.count(), 1);
     QTRY_COMPARE(m_dirLister.spyCompleted.count(), 1);
     QCOMPARE(m_dirLister.spyCompletedQUrl.count(), 1);
@@ -363,7 +364,7 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     const int origItemCount = m_items.count();
     QCOMPARE(fileCount(), origItemCount);
     const QString path = tempPath();
-    QTemporaryFile tempFile;
+    QTemporaryFile tempFile(tmpDirTemplate() + QStringLiteral("_normal_file"));
     QVERIFY(tempFile.open());
     const QString symPath = tempFile.fileName() + "_link";
     tempFile.close();
@@ -386,7 +387,7 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     QTRY_COMPARE(m_items.count(), origItemCount);
     QTRY_VERIFY(dirLister2.isFinished());
 
-    QTest::qWait(100); // We need a 1s timestamp difference on the dir, otherwise FAM won't notice anything.
+    QTest::qWait(1000); // We need a 1s timestamp difference on the dir, otherwise FAM won't notice anything.
 
     qDebug() << "Creating new file";
     const QString fileName = QStringLiteral("toplevelfile_newinlink");
@@ -410,7 +411,7 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     // Test file deletion
     {
         qDebug() << "Deleting" << (path + fileName);
-        QTest::qWait(100); // for timestamp difference
+        QTest::qWait(1000); // for timestamp difference
         QFile::remove(path + fileName);
         QTRY_COMPARE(dirLister2.spyItemsDeleted.count(), 1);
         QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 1);
@@ -420,19 +421,14 @@ void KDirListerTest::testNewItemsInSymlink() // #213799
     // Test file deletion in symlink dir #469254
     {
         qDebug() << "Deleting" << (symPath + "/" + fileName2);
-        QTest::qWait(100); // for timestamp difference
+        QTest::qWait(1000); // for timestamp difference
         QFile::remove(symPath + "/" + fileName2);
         QTRY_COMPARE(dirLister2.spyItemsDeleted.count(), 2);
         QTRY_COMPARE(m_dirLister.spyItemsDeleted.count(), 2);
         const KFileItem item = dirLister2.spyItemsDeleted[1][0].value<KFileItemList>().at(0);
         QCOMPARE(item.url().toLocalFile(), QString(symPath + '/' + fileName2));
     }
-
-    // TODO: test file update.
-    disconnect(&m_dirLister, nullptr, this, nullptr);
-
     QFile::remove(symPath);
-    m_dirLister.openUrl(QUrl::fromLocalFile(tempPath()));
 }
 
 // This test assumes testOpenUrl was run before. So m_dirLister is holding the items already.
@@ -833,7 +829,7 @@ void KDirListerTest::testConcurrentListingAndStop()
     MyDirLister dirLister2;
 
     // Use a new tempdir for this test, so that we don't use the cache at all.
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     const QString path = tempDir.path() + '/';
     createTestFile(path + "file_1");
     createTestFile(path + "file_2");
@@ -1025,7 +1021,7 @@ void KDirListerTest::testBug211472()
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + "/newsubdir/";
     QDir().mkdir(path);
     MyDirLister dirLister;
@@ -1196,7 +1192,7 @@ void KDirListerTest::testListEmptyDirFromCache() // #278431
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QUrl url = QUrl::fromLocalFile(newDir.path());
 
     // List and watch an empty dir
@@ -1232,7 +1228,7 @@ void KDirListerTest::testWatchingAfterCopyJob() // #331582
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + '/';
 
     // List and watch an empty dir
@@ -1284,7 +1280,7 @@ void KDirListerTest::testRemoveWatchedDirectory()
 {
     m_items.clear();
 
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + '/';
 
     // List and watch an empty dir
@@ -1325,14 +1321,16 @@ void KDirListerTest::testRemoveWatchedDirectory()
 
 void KDirListerTest::testDirPermissionChange()
 {
-    QSKIP("TODO testDirPermissionChange doesn't pass FIXME");
-
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
 
     const QString path = tempDir.path() + '/';
     const QString subdir = path + QLatin1String("subdir");
     QVERIFY(QDir().mkdir(subdir));
 
+    // ensure initial permissions are different to the ones we set below
+    const mode_t initPermissions = (S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IXGRP);
+    QVERIFY(KIO::chmod(QUrl::fromLocalFile(subdir), initPermissions)->exec());
+
     MyDirLister mylister;
     mylister.openUrl(QUrl::fromLocalFile(tempDir.path()));
     QSignalSpy spyCompleted(&mylister, qOverload<>(&KCoreDirLister::completed));
@@ -1464,7 +1462,7 @@ void KDirListerTest::testRenameDirectory() // #401552
 void KDirListerTest::testRequestMimeType()
 {
     // Use a new tempdir and lister instance for this test, so that we don't use any cache at all.
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     QString path = tempDir.path() + QLatin1Char('/');
 
     createTestFile(path + "/file_1");
@@ -1526,7 +1524,7 @@ void KDirListerTest::testMimeFilter_data()
 void KDirListerTest::testMimeFilter()
 {
     // Use a new tempdir and lister instance for this test, so that we don't use any cache at all.
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     QString path = tempDir.path() + '/';
 
     QFETCH(QStringList, files);
@@ -1576,7 +1574,7 @@ void KDirListerTest::testDeleteCurrentDir()
 
 void KDirListerTest::testForgetDir()
 {
-    QTemporaryDir tempDir(homeTmpDir());
+    QTemporaryDir tempDir(tmpDirTemplate());
     QString path = tempDir.path();
     createTestFile(path + "/file_1");
 
@@ -1646,7 +1644,7 @@ void KDirListerTest::waitUntilAfter(const QDateTime &ctime)
 // and stop watching a directory because a separate lister left a directory open in another lister
 void KDirListerTest::testBug386763()
 {
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
     const QString path = newDir.path() + "/newsubdir/";
     const QString otherpath = newDir.path() + "/othersubdir/";
 
@@ -1685,7 +1683,7 @@ void KDirListerTest::testBug386763()
 
 void KDirListerTest::testCacheEviction()
 {
-    QTemporaryDir newDir(homeTmpDir());
+    QTemporaryDir newDir(tmpDirTemplate());
 
     MyDirLister dirLister;
     dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
